@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2004-2009, 2011-2013
+  Copyright (C) 2004-2009, 2011-2013, 2017
   Rocky Bernstein <rocky@gnu.org>
 
   This program is free software: you can redistribute it and/or modify
@@ -108,7 +108,6 @@ cdio_generic_free (void *p_user_data)
 
   if (NULL != p_env->cdtext) {
       cdtext_destroy(p_env->cdtext);
-      free(p_env->cdtext);
       p_env->cdtext = NULL;
   }
 
@@ -286,6 +285,8 @@ get_cdtext_generic (void *p_user_data)
 
   if (!p_env) return NULL;
 
+  if (p_env->b_cdtext_error) return NULL;
+
   if (NULL == p_env->cdtext) {
     p_cdtext_data = read_cdtext_generic (p_env);
 
@@ -318,6 +319,8 @@ get_discmode_generic (void *p_user_data )
   /* See if this is a DVD. */
   cdio_dvd_struct_t dvd;  /* DVD READ STRUCT for layer 0. */
 
+  memset(&dvd, 0, sizeof(dvd));
+
   dvd.physical.type = CDIO_DVD_STRUCT_PHYSICAL;
   dvd.physical.layer_num = 0;
   if (0 == mmc_get_dvd_struct_physical (p_env->cdio, &dvd)) {
@@ -456,9 +459,7 @@ uint8_t *
 read_cdtext_generic(void *p_env)
 {
   generic_img_private_t *p_user_data = p_env;
-  return mmc_read_cdtext_private (p_user_data,
-                                  p_user_data->cdio->op.run_mmc_cmd
-                                  );
+  return mmc_read_cdtext ( p_user_data->cdio );
 }
 
 /*! Return number of channels in track: 2 or 4; -2 if not
