@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2004-2008, 2011-2012, 2014
+  Copyright (C) 2004-2008, 2011-2012, 2014, 2017
   Rocky Bernstein <rocky@gnu.org>
     toc reading routine adapted from cuetools
   Copyright (C) 2003 Svend Sanjay Sorensen <ssorensen@fastmail.fm>
@@ -357,16 +357,16 @@ parse_tocfile (_img_private_t *cd, const char *psz_cue_name)
 	      goto err_exit;
 	    } else {
 	      /* Check that we have all digits*/
-	      unsigned int i;
-	      for (i=0; i<13; i++) {
-		if (!isdigit((unsigned char) psz_field[i])) {
+	      unsigned int j;
+	      for (j=0; j<13; j++) {
+		if (!isdigit((unsigned char) psz_field[j])) {
 		    cdio_log(log_level,
 			     "%s line %d after word CATALOG:",
 			     psz_cue_name, i_line);
 		    cdio_log(log_level,
 			     "Character \"%c\" at postition %i of token \"%s\""
 			     " is not all digits.",
-			     psz_field[i], i+1, psz_field);
+			     psz_field[j], j+1, psz_field);
 		    goto err_exit;
 		}
 	      }
@@ -715,6 +715,7 @@ parse_tocfile (_img_private_t *cd, const char *psz_cue_name)
 		cdio_log (log_level,
 			  "%s line %d: can't open file `%s' for reading",
 			  psz_cue_name, i_line, psz_field);
+		cdio_stdio_destroy (s);
 		goto err_exit;
 	      }
 	      cdio_stdio_destroy (s);
