@@ -1,9 +1,9 @@
 /*
-  Copyright (C) 2005, 2006, 2008, 2009, 2010, 2011, 2012
+  Copyright (C) 2005, 2006, 2008, 2009, 2010, 2011, 2012, 2017
   Rocky Bernstein <rocky@gnu.org>
 
   Adapted from Gerd Knorr's player.c program  <kraxel@bytesex.org>
-  Copyright (C) 1997, 1998 
+  Copyright (C) 1997, 1998
 
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -56,13 +56,13 @@
 
 #ifdef HAVE_CURSES_H
 # include <curses.h>
-#else 
+#else
 # ifdef HAVE_NCURSES_H
 #include <ncurses.h>
 # else
 #   ifdef HAVE_NCURSES_NCURSES_H
 #     include <ncurses/ncurses.h>
-#   else 
+#   else
 #     error "You need <curses.h> or <ncurses.h to build cdda-player"
 #   endif
 # endif
@@ -78,7 +78,7 @@
 #include "getopt.h"
 
 static void action(const char *psz_action);
-static void display_cdinfo(CdIo_t *p_cdio, track_t i_tracks, 
+static void display_cdinfo(CdIo_t *p_cdio, track_t i_tracks,
                            track_t i_first_track);
 static void display_tracks(void);
 static void get_cddb_track_info(track_t i_track);
@@ -86,17 +86,17 @@ static void get_cdtext_track_info(track_t i_track);
 static void get_track_info(track_t i_track);
 static bool play_track(track_t t1, track_t t2);
 
-static CdIo_t             *p_cdio;               /* libcdio handle */
+static CdIo_t             *p_cdio_global;        /* libcdio handle */
 static driver_id_t        driver_id = DRIVER_DEVICE;
 static int b_sig = false;                        /* set on some signals */
 
 /* cdrom data */
-static track_t            i_first_track;
+static track_t            i_first_track_global;
 static track_t            i_last_track;
 static track_t            i_first_audio_track;
 static track_t            i_last_audio_track;
 static track_t            i_last_display_track = CDIO_INVALID_TRACK;
-static track_t            i_tracks;
+static track_t            i_tracks_global;
 static msf_t              toc[CDIO_CDROM_LEADOUT_TRACK+1];
 static cdio_subchannel_t  sub;      /* subchannel last time read */
 static int                i_data;     /* # of data tracks present ? */
@@ -105,7 +105,7 @@ static int                stop_track = 0;
 static int                one_track = 0;
 static int                i_vol_port   = 5; /* If 5, retrieve volume port.
                                          Otherwise the port number 0..3
-                                         of a working volume port and 
+                                         of a working volume port and
                                          4 for no working port.
                                        */
 
@@ -115,7 +115,7 @@ static bool               auto_mode       = false;
 static bool               b_verbose       = false;
 static bool               debug           = false;
 static bool               b_interactive   = true;
-static bool               b_prefer_cdtext = true; 
+static bool               b_prefer_cdtext = true;
 #ifdef CDDB_ADDED
 static bool               b_cddb          = false; /* CDDB database present */
 #endif
@@ -126,12 +126,12 @@ static bool               b_all_tracks = false; /* True if we display all tracks
 static int8_t             i_volume_level = -1;   /* Valid range is 0..100 */
 
 
-static char *psz_device=NULL;
+static char *psz_device_global=NULL;
 static char *psz_program;
 
 /* Info about songs and titles. The 0 entry will contain the disc info.
  */
-typedef struct 
+typedef struct
 {
   char title[80];
   char artist[80];
@@ -211,7 +211,7 @@ static unsigned int  LINE_ACTION = 25;
 static unsigned int  COLS_LAST;
 static char psz_action_line[300] = "";
 
-static int rounded_div(unsigned int i_a, unsigned int i_b) 
+static int rounded_div(unsigned int i_a, unsigned int i_b)
 {
   const unsigned int i_b_half=i_b/2;
   return ((i_a)+i_b_half)/i_b;
@@ -219,10 +219,10 @@ static int rounded_div(unsigned int i_a, unsigned int i_b)
 
 /** Curses window initialization. */
 static void
-tty_raw()
+tty_raw(void)
 {
   if (!b_interactive) return;
-  
+
   initscr();
   cbreak();
   clear();
@@ -237,16 +237,18 @@ tty_raw()
 
 /** Curses window finalization. */
 static void
-tty_restore()
+tty_restore(void)
 {
   if (!b_interactive) return;
   endwin();
 }
 
+#define UNUSED(x) (void)(x)
 /* Called when window is resized. */
-static void 
-sigwinch()
+static void
+sigwinch(int dummy)
 {
+  UNUSED(dummy);
   tty_restore();
   tty_raw();
   action(NULL);
@@ -254,7 +256,7 @@ sigwinch()
 
 /* Signal handler - Ctrl-C and others. */
 static void
-ctrlc(int signal)
+ctrlc(int signal_num)
 {
   b_sig = true;
 }
@@ -265,7 +267,7 @@ select_wait(int sec)
 {
   struct timeval  tv;
   fd_set          se;
-  
+
   FD_ZERO(&se);
   FD_SET(0,&se);
   tv.tv_sec = sec;
@@ -276,7 +278,7 @@ select_wait(int sec)
 /* ---------------------------------------------------------------------- */
 
 /* Display the action line. */
-static void 
+static void
 action(const char *psz_action)
 {
   if (!b_interactive) {
@@ -284,11 +286,11 @@ action(const char *psz_action)
       fprintf(stderr,"action: %s\n", psz_action);
     return;
   }
-  
-  if (!psz_action) 
+
+  if (!psz_action)
     psz_action = psz_action_line;
   else if (psz_action && strlen(psz_action))
-    snprintf(psz_action_line, sizeof(psz_action_line), "action : %s", 
+    snprintf(psz_action_line, sizeof(psz_action_line), "action : %s",
              psz_action);
   else
     snprintf(psz_action_line, sizeof(psz_action_line), "%s", "" );
@@ -299,11 +301,11 @@ action(const char *psz_action)
 
 
 /* Display an error message.. */
-static void 
+static void
 xperror(const char *psz_msg)
 {
   char line[80];
-  
+
   if (!b_interactive) {
     if (b_verbose) {
       fprintf(stderr, "error: ");
@@ -311,7 +313,7 @@ xperror(const char *psz_msg)
     }
     return;
   }
-  
+
   if (b_verbose) {
     snprintf(line, sizeof(line), "%s: %s", psz_msg, strerror(errno));
     attron(A_STANDOUT);
@@ -324,7 +326,7 @@ xperror(const char *psz_msg)
   }
 }
 
-static void 
+static void
 finish(const char *psz_msg, int rc)
 {
   if (b_interactive) {
@@ -340,8 +342,8 @@ finish(const char *psz_msg, int rc)
   cddb_disc_destroy(p_cddb_disc);
   libcddb_shutdown();
 #endif /*HAVE_CDDB*/
-  cdio_destroy (p_cdio);
-  free (psz_device);
+  cdio_destroy (p_cdio_global);
+  free (psz_device_global);
   exit (rc);
 }
 
@@ -351,7 +353,7 @@ finish(const char *psz_msg, int rc)
    0..100.
 */
 static bool
-set_volume_level(CdIo_t *p_cdio, uint8_t i_level) 
+set_volume_level(CdIo_t *p_cdio, uint8_t i_level)
 {
   const unsigned int i_new_level= rounded_div(i_level*256, 100);
   unsigned int i;
@@ -359,11 +361,11 @@ set_volume_level(CdIo_t *p_cdio, uint8_t i_level)
   for (i=0; i<=3; i++) {
     audio_volume.level[i] = i_new_level;
   }
-  
+
   rc = cdio_audio_set_volume(p_cdio, &audio_volume);
   if ( DRIVER_OP_SUCCESS != rc ) {
     /* If we can't do a get volume, audio_volume.level is used as
-       a second-best guess. But if this set failed restore it to 
+       a second-best guess. But if this set failed restore it to
        an invalid value so we don't get confused and think that this
        was set. */
     for (i=0; i<=3; i++) {
@@ -374,7 +376,7 @@ set_volume_level(CdIo_t *p_cdio, uint8_t i_level)
     i_vol_port=0;
   }
   return rc;
-  
+
 }
 
 /* Subtract one from the volume level. If we are at the minimum value,
@@ -388,7 +390,7 @@ set_volume_level(CdIo_t *p_cdio, uint8_t i_level)
    See issue #33333
 
    If the volume level is undefined, then this means we could not get
-   the current value and we'll' set it to 50 the midway point.  
+   the current value and we'll' set it to 50 the midway point.
 
    Return the status of setting the volume level.  */
 static bool
@@ -410,7 +412,7 @@ decrease_volume_level(CdIo_t *p_cdio)
    See issue #33333
 
    If volume level is undefined, then this means we could not get the
-   current value and we'll' set it to 50 the midway point.  
+   current value and we'll' set it to 50 the midway point.
 
    Return the status of setting the volume level.  */
 static bool
@@ -443,15 +445,15 @@ static bool
 cd_eject(void)
 {
   bool b_ok = true;
-  if (p_cdio) {
-    cd_stop(p_cdio);
+  if (p_cdio_global) {
+    cd_stop(p_cdio_global);
     action("eject...");
-    b_ok = DRIVER_OP_SUCCESS == cdio_eject_media(&p_cdio);
+    b_ok = DRIVER_OP_SUCCESS == cdio_eject_media(&p_cdio_global);
     if (!b_ok)
       xperror("eject");
     b_cd = false;
-    cdio_destroy (p_cdio);
-    p_cdio = NULL;
+    cdio_destroy (p_cdio_global);
+    p_cdio_global = NULL;
   }
   return b_ok;
 }
@@ -501,10 +503,10 @@ read_subchannel(CdIo_t *p_cdio)
 }
 
 #ifdef HAVE_CDDB
-/** This routine is called by vcd routines on error. 
+/** This routine is called by vcd routines on error.
    Setup is done by init_input_plugin.
 */
-static void 
+static void
 cddb_log_handler (cddb_log_level_t level, const char message[])
 {
   switch (level) {
@@ -520,17 +522,17 @@ cddb_log_handler (cddb_log_level_t level, const char message[])
     xperror(message);
     break;
   }
-  
+
   /* gl_default_cdio_log_handler (level, message); */
 }
 #endif /* HAVE_CDDB  */
 
-static void 
-get_cddb_disc_info(CdIo_t *p_cdio) 
+static void
+get_cddb_disc_info(CdIo_t *p_cdio)
 {
 #ifdef HAVE_CDDB
-  b_db = init_cddb(p_cdio, &p_conn, &p_cddb_disc, xperror, i_first_track, 
-                   i_tracks, &i_cddb_matches);
+  b_db = init_cddb(p_cdio, &p_conn, &p_cddb_disc, xperror, i_first_track_global,
+                   i_tracks_global, &i_cddb_matches);
   if (b_db) {
     int i_year;
     i_year = atoi(year);
@@ -550,8 +552,8 @@ get_cddb_disc_info(CdIo_t *p_cdio)
     b_cdtext_ ## info_field = true;                             \
   }
 
-static void 
-get_cdtext_disc_info(CdIo_t *p_cdio) 
+static void
+get_cdtext_disc_info(CdIo_t *p_cdio)
 {
   cdtext_t *p_cdtext = cdio_get_cdtext(p_cdio);
 
@@ -562,8 +564,8 @@ get_cdtext_disc_info(CdIo_t *p_cdio)
   }
 }
 
-static void 
-get_disc_info(CdIo_t *p_cdio) 
+static void
+get_disc_info(CdIo_t *p_cdio)
 {
   b_db = false;
   if (b_prefer_cdtext) {
@@ -586,19 +588,19 @@ read_toc(CdIo_t *p_cdio)
   memset(cd_info, 0, sizeof(cd_info));
   title[0] = artist[0] = genre[0] = category[0] = year[0] = '\0';
 
-  i_first_track       = cdio_get_first_track_num(p_cdio);
-  i_last_track        = cdio_get_last_track_num(p_cdio);
-  i_tracks            = cdio_get_num_tracks(p_cdio);
-  i_first_audio_track = i_first_track;
-  i_last_audio_track  = i_last_track;
+  i_first_track_global = cdio_get_first_track_num(p_cdio);
+  i_last_track         = cdio_get_last_track_num(p_cdio);
+  i_tracks_global      = cdio_get_num_tracks(p_cdio);
+  i_first_audio_track  = i_first_track_global;
+  i_last_audio_track   = i_last_track;
 
 
   cdio_audio_get_volume(p_cdio, &audio_volume);
   for (i_vol_port=0; i_vol_port<4; i_vol_port++) {
     if (audio_volume.level[i_vol_port] > 0) break;
   }
-  
-  if ( CDIO_INVALID_TRACK == i_first_track ||
+
+  if ( CDIO_INVALID_TRACK == i_first_track_global ||
        CDIO_INVALID_TRACK == i_last_track ) {
     xperror("read toc header");
     b_cd = false;
@@ -608,7 +610,7 @@ read_toc(CdIo_t *p_cdio)
     b_cd = true;
     i_data = 0;
     get_disc_info(p_cdio);
-    for (i = i_first_track; i <= i_last_track+1; i++) {
+    for (i = i_first_track_global; i <= i_last_track+1; i++) {
       int s;
       if ( !cdio_get_track_msf(p_cdio, i, &(toc[i])) )
       {
@@ -617,19 +619,20 @@ read_toc(CdIo_t *p_cdio)
         return;
       }
       if ( TRACK_FORMAT_AUDIO == cdio_get_track_format(p_cdio, i) ) {
-        
-        if (i != i_first_track) 
+
+        if (i != i_first_track_global)
           {
-            s = cdio_audio_get_msf_seconds(&toc[i]) 
+            s = cdio_audio_get_msf_seconds(&toc[i])
               - cdio_audio_get_msf_seconds(&toc[i-1]);
-            snprintf(cd_info[i-1].length, sizeof(cd_info[0].length), 
+            snprintf(cd_info[i-1].length, sizeof(cd_info[0].length),
                      "%02d:%02d",
-                     s / CDIO_CD_SECS_PER_MIN,  s % CDIO_CD_SECS_PER_MIN);
+                     (uint8_t) (s / CDIO_CD_SECS_PER_MIN),
+                     (uint8_t) (s % CDIO_CD_SECS_PER_MIN));
           }
       } else {
         if ((i != i_last_track+1) ) {
           i_data++;
-          if (i == i_first_track) {
+          if (i == i_first_track_global) {
             if (i == i_last_track)
               i_first_audio_track = CDIO_CDROM_LEADOUT_TRACK;
             else
@@ -646,7 +649,7 @@ read_toc(CdIo_t *p_cdio)
   }
   action("");
   if (!b_all_tracks)
-    display_cdinfo(p_cdio, i_tracks, i_first_track);
+    display_cdinfo(p_cdio, i_tracks_global, i_first_track_global);
 }
 
 /** Play an audio track. */
@@ -655,30 +658,30 @@ play_track(track_t i_start_track, track_t i_end_track)
 {
   bool b_ok = true;
   char line[80];
-  
+
   if (!b_cd) {
-    read_toc(p_cdio);
+    read_toc(p_cdio_global);
   }
-  
-  read_subchannel(p_cdio);
-  if (!b_cd || i_first_track == CDIO_CDROM_LEADOUT_TRACK)
+
+  read_subchannel(p_cdio_global);
+  if (!b_cd || i_first_track_global == CDIO_CDROM_LEADOUT_TRACK)
     return false;
-  
+
   if (debug)
     fprintf(stderr,"play tracks: %d-%d => ", i_start_track, i_end_track-1);
-  if (i_start_track < i_first_track)       i_start_track = i_first_track;
-  if (i_start_track > i_last_audio_track)  i_start_track = i_last_audio_track;
-  if (i_end_track < i_first_track)         i_end_track   = i_first_track;
-  if (i_end_track > i_last_audio_track)    i_end_track   = i_last_audio_track;
+  if (i_start_track < i_first_track_global)  i_start_track = i_first_track_global;
+  if (i_start_track > i_last_audio_track)    i_start_track = i_last_audio_track;
+  if (i_end_track < i_first_track_global)    i_end_track   = i_first_track_global;
+  if (i_end_track > i_last_audio_track)      i_end_track   = i_last_audio_track;
   i_end_track++;
   if (debug)
     fprintf(stderr,"%d-%d\n",i_start_track, i_end_track-1);
-  
-  cd_pause(p_cdio);
-  snprintf(line, sizeof(line), "play track %d to track %d.", 
+
+  cd_pause(p_cdio_global);
+  snprintf(line, sizeof(line), "play track %d to track %d.",
 	   i_start_track, i_end_track-1);
   action(line);
-  b_ok = (DRIVER_OP_SUCCESS == cdio_audio_play_msf(p_cdio, 
+  b_ok = (DRIVER_OP_SUCCESS == cdio_audio_play_msf(p_cdio_global,
                                                    &(toc[i_start_track]),
                                                    &(toc[i_end_track])) );
   if (!b_ok) xperror("play");
@@ -690,44 +693,44 @@ skip(int diff)
 {
   msf_t start_msf;
   int   sec;
-  
-  read_subchannel(p_cdio);
-  if (!b_cd ||  i_first_track == CDIO_CDROM_LEADOUT_TRACK)
+
+  read_subchannel(p_cdio_global);
+  if (!b_cd ||  i_first_track_global == CDIO_CDROM_LEADOUT_TRACK)
     return;
-  
+
   sec  = cdio_audio_get_msf_seconds(&sub.abs_addr);
   sec += diff;
   if (sec < 0) sec = 0;
-  
+
   start_msf.m = cdio_to_bcd8(sec / CDIO_CD_SECS_PER_MIN);
   start_msf.s = cdio_to_bcd8(sec % CDIO_CD_SECS_PER_MIN);
   start_msf.f = 0;
-  
-  cd_pause(p_cdio);
-  if ( DRIVER_OP_SUCCESS != cdio_audio_play_msf(p_cdio, &start_msf, 
+
+  cd_pause(p_cdio_global);
+  if ( DRIVER_OP_SUCCESS != cdio_audio_play_msf(p_cdio_global, &start_msf,
                                                 &(toc[i_last_audio_track])) )
     xperror("play");
 }
 
 static bool
-toggle_pause()
+toggle_pause(void)
 {
   bool b_ok = true;
   if (!b_cd) return false;
-  
+
   if (CDIO_MMC_READ_SUB_ST_PAUSED == sub.audio_status) {
-    b_ok = DRIVER_OP_SUCCESS != cdio_audio_resume(p_cdio);
+    b_ok = DRIVER_OP_SUCCESS != cdio_audio_resume(p_cdio_global);
     if (!b_ok)
       xperror("resume");
   } else {
-    b_ok = DRIVER_OP_SUCCESS != cdio_audio_pause(p_cdio);
+    b_ok = DRIVER_OP_SUCCESS != cdio_audio_pause(p_cdio_global);
     if (!b_ok)
       xperror("pause");
   }
   return b_ok;
 }
 
-/** Update windows with status and possibly track info. This used in 
+/** Update windows with status and possibly track info. This used in
   interactive playing not batch mode.
  */
 static void
@@ -738,63 +741,63 @@ display_status(bool b_status_only)
   if (!b_interactive) return;
 
   if (!b_cd) {
-    snprintf(line, sizeof(line), "no CD in drive (%s)", psz_device);
+    snprintf(line, sizeof(line), "no CD in drive (%s)", psz_device_global);
 
-  } else if (i_first_track == CDIO_CDROM_LEADOUT_TRACK) {
+  } else if (i_first_track_global == CDIO_CDROM_LEADOUT_TRACK) {
     snprintf(line, sizeof(line), "CD has only data tracks");
-    
+
   } else if (sub.audio_status == CDIO_MMC_READ_SUB_ST_PAUSED ||
              sub.audio_status == CDIO_MMC_READ_SUB_ST_PLAY) {
-    cdio_audio_get_volume(p_cdio, &audio_volume);
+    cdio_audio_get_volume(p_cdio_global, &audio_volume);
     if (i_vol_port < 4) {
         i_volume_level = rounded_div(audio_volume.level[i_vol_port]*100, 256);
         snprintf(line, sizeof(line),
                 "track %2d - %02x:%02x of %s (%02x:%02x abs) %s volume: %d",
-                sub.track, sub.rel_addr.m, sub.rel_addr.s, 
+                sub.track, sub.rel_addr.m, sub.rel_addr.s,
                 cd_info[sub.track].length,
                 sub.abs_addr.m, sub.abs_addr.s,
                 mmc_audio_state2str(sub.audio_status),
                 i_volume_level);
-      } else 
-        snprintf(line, sizeof(line), 
+      } else
+        snprintf(line, sizeof(line),
 		 "track %2d - %02x:%02x of %s (%02x:%02x abs) %s",
 		 sub.track, sub.rel_addr.m, sub.rel_addr.s,
 		 cd_info[sub.track].length, sub.abs_addr.m, sub.abs_addr.s,
 		 mmc_audio_state2str(sub.audio_status));
   } else {
     snprintf(line, sizeof(line), "%s", mmc_audio_state2str(sub.audio_status));
-    
+
   }
 
   action(NULL);
   mvprintw(LINE_STATUS, 0, (char *) "status%s: %s",
            auto_mode ? "*" : " ", line);
   clrtoeol();
-  
-  if ( !b_status_only && b_db && i_last_display_track != sub.track && 
+
+  if ( !b_status_only && b_db && i_last_display_track != sub.track &&
        (sub.audio_status == CDIO_MMC_READ_SUB_ST_PAUSED ||
         sub.audio_status == CDIO_MMC_READ_SUB_ST_PLAY)  &&
         b_cd) {
 
-    if (b_all_tracks) 
+    if (b_all_tracks)
       display_tracks();
     else {
       const cd_track_info_rec_t *p_cd_info = &cd_info[sub.track];
       i_last_display_track = sub.track;
-      if (i_first_audio_track != sub.track && 
+      if (i_first_audio_track != sub.track &&
           strlen(cd_info[sub.track-1].title)) {
-        const cd_track_info_rec_t *p_cd_info = &cd_info[sub.track-1];
+        const cd_track_info_rec_t *p_cd_info_track = &cd_info[sub.track-1];
         mvprintw(LINE_TRACK_PREV, 0, (char *) " track %2d title : %s [%s]",
-                 sub.track-1, p_cd_info->title, 
-                 p_cd_info->b_cdtext ? "CD-Text" : "CDDB");
+                 sub.track-1, p_cd_info->title,
+                 p_cd_info_track->b_cdtext ? "CD-Text" : "CDDB");
         clrtoeol();
       } else {
         mvprintw(LINE_TRACK_PREV, 0, (char *) "%s","");
         clrtoeol();
       }
       if (strlen(p_cd_info->title)) {
-        mvprintw(LINE_TRACK_TITLE,  0, (char *) ">track %2d title : %s [%s]", 
-                 sub.track, p_cd_info->title, 
+        mvprintw(LINE_TRACK_TITLE,  0, (char *) ">track %2d title : %s [%s]",
+                 sub.track, p_cd_info->title,
                  (char *) (p_cd_info->b_cdtext ? "CD-Text" : "CDDB"));
         clrtoeol();
       }
@@ -804,11 +807,11 @@ display_status(bool b_status_only)
                  p_cd_info->b_cdtext ? "CD-Text" : "CDDB");
         clrtoeol();
       }
-      if (i_last_audio_track != sub.track && 
+      if (i_last_audio_track != sub.track &&
           strlen(cd_info[sub.track+1].title)) {
-        const cd_track_info_rec_t *p_cd_info = &cd_info[sub.track+1];
-        mvprintw(LINE_TRACK_NEXT, 0, (char *) " track %2d title : %s [%s]", 
-                 sub.track+1, p_cd_info->title,
+        const cd_track_info_rec_t *p_cd_info_track = &cd_info[sub.track+1];
+        mvprintw(LINE_TRACK_NEXT, 0, (char *) " track %2d title : %s [%s]",
+                 sub.track+1, p_cd_info_track->title,
                  p_cd_info->b_cdtext ? "CD-Text" : "CDDB");
         clrtoeol();
       } else {
@@ -827,16 +830,16 @@ static void
 get_cddb_track_info(track_t i_track)
 {
 #ifdef HAVE_CDDB
-  cddb_track_t *t = cddb_disc_get_track(p_cddb_disc, 
-                                        i_track - i_first_track);
+  cddb_track_t *t = cddb_disc_get_track(p_cddb_disc,
+                                        i_track - i_first_track_global);
   if (t) {
     cddb_track_set_title(t, title);
     cddb_track_set_artist(t, artist);
   }
-  
+
 #else
     ;
-#endif      
+#endif
 }
 
 #define add_cdtext_track_info(format_str, info_field, FIELD) \
@@ -852,7 +855,7 @@ static void
 get_cdtext_track_info(track_t i_track)
 {
 
-  cdtext_t *p_cdtext = cdio_get_cdtext(p_cdio);
+  cdtext_t *p_cdtext = cdio_get_cdtext(p_cdio_global);
 
   if (NULL != p_cdtext) {
     add_cdtext_track_info("%s", title, CDTEXT_FIELD_TITLE);
@@ -880,13 +883,13 @@ get_track_info(track_t i_track)
              b_cdtext_ ## field ? "CD-Text": "CDDB");      \
     clrtoeol();                                            \
   }
-    
+
 static void
 display_cdinfo(CdIo_t *p_cdio, track_t i_tracks, track_t i_first_track)
 {
   int len;
   char line[80];
-  
+
   if (!b_interactive) return;
 
   if (!b_cd) snprintf(line, sizeof(line), "-");
@@ -895,21 +898,21 @@ display_cdinfo(CdIo_t *p_cdio, track_t i_tracks, track_t i_first_track)
                   (unsigned int) i_last_track,
                   toc[i_last_track+1].m, toc[i_last_track+1].s);
     if (i_data && i_first_track != CDIO_CDROM_LEADOUT_TRACK)
-      snprintf(line+len, sizeof(line)-len, ", audio=%u-%u", 
+      snprintf(line+len, sizeof(line)-len, ", audio=%u-%u",
 	      (unsigned int) i_first_audio_track,
               (unsigned int) i_last_audio_track);
-    
+
     display_line(LINE_ARTIST, 0, "CD Artist       : %s", artist);
     display_line(LINE_CDNAME, 0, "CD Title        : %s", title);
     display_line(LINE_GENRE,  0, "CD Genre        : %s", genre);
     display_line(LINE_YEAR,   0, "CD Year         : %s", year);
   }
-  
-  mvprintw(LINE_CDINFO, 0, (char *) "CD info: %0s", line);
+
+  mvprintw(LINE_CDINFO, 0, (char *) "CD info: %s", line);
   clrtoeol();
   action(NULL);
 }
-    
+
 /* ---------------------------------------------------------------------- */
 
 static void
@@ -948,20 +951,20 @@ usage(char *prog)
             "to play it, and when it is done it ejects the CD. Start it that\n"
             "way on a spare console and forget about it...\n"
             "\n"
-            "(c) 1997,98 Gerd Knorr <kraxel@goldbach.in-berlin.de>\n"
-            "(c) 2005, 2006 Rocky Bernstein <rocky@gnu.org>\n"
+            "(c) 1997-98 Gerd Knorr <kraxel@goldbach.in-berlin.de>\n"
+            "(c) 2005-2006, 2017 Rocky Bernstein <rocky@gnu.org>\n"
             , prog, prog);
 }
 
 static void
-print_keys()
+print_keys(void)
 {
   unsigned int i;
   for (i=0; i < i_key_bindings; i++)
     fprintf(stderr, "%s\n", key_bindings[i]);
 }
 
-static void 
+static void
 keypress_wait(CdIo_t *p_cdio)
   {
     action("press any key to continue");
@@ -973,19 +976,19 @@ keypress_wait(CdIo_t *p_cdio)
     clrtobot();
     action(NULL);
     if (!b_all_tracks)
-      display_cdinfo(p_cdio, i_tracks, i_first_track);
+      display_cdinfo(p_cdio, i_tracks_global, i_first_track_global);
     i_last_display_track = CDIO_INVALID_TRACK;
   }
 
 static void
-list_keys()
+list_keys(void)
 {
   unsigned int i;
   for (i=0; i < i_key_bindings; i++) {
     mvprintw(LINE_TRACK_PREV+i, 0, (char *) "%s", key_bindings[i]);
     clrtoeol();
   }
-  keypress_wait(p_cdio);
+  keypress_wait(p_cdio_global);
 }
 
 static void
@@ -997,12 +1000,12 @@ display_tracks(void)
 
   if (b_record) {
     i_line=LINE_TRACK_PREV - 1;
-    for (i = i_first_track; i <= i_last_track; i++) {
+    for (i = i_first_track_global; i <= i_last_track; i++) {
       char line[200]="";
-      s = cdio_audio_get_msf_seconds(&toc[i+1]) 
+      s = cdio_audio_get_msf_seconds(&toc[i+1])
         - cdio_audio_get_msf_seconds(&toc[i]);
-      read_subchannel(p_cdio);
-      snprintf(line, sizeof(line), "%2d  %02d:%02d  %s ", i, 
+      read_subchannel(p_cdio_global);
+      snprintf(line, sizeof(line), "%2d  %02d:%02d  %s ", i,
               s / CDIO_CD_SECS_PER_MIN,  s % CDIO_CD_SECS_PER_MIN,
               ( ( sub.audio_status == CDIO_MMC_READ_SUB_ST_PLAY ||
                   sub.audio_status == CDIO_MMC_READ_SUB_ST_PAUSED ) &&
@@ -1020,7 +1023,7 @@ display_tracks(void)
         attron(A_STANDOUT);
         mvprintw(i_line++, 0, line);
         attroff(A_STANDOUT);
-      } else 
+      } else
         mvprintw(i_line++, 0, line);
       clrtoeol();
     }
@@ -1286,16 +1289,16 @@ static void
 ps_list_tracks(void)
 {
   int i,s,y,sy;
-  
+
   if (!b_record) return;
 
   printf("%%!PS-Adobe-2.0\n");
-  
+
   /* encoding tricks */
   puts(ENCODING_TRICKS);
   printf("/Times /TimesLatin1 charvec ReEncodeSmall\n");
   printf("/Helvetica /HelveticaLatin1 charvec ReEncodeSmall\n");
-  
+
   /* Spaces */
   printf("0 setlinewidth\n");
   printf(" 100 100 moveto\n");
@@ -1303,29 +1306,30 @@ ps_list_tracks(void)
   printf("   0 330 rlineto\n");
   printf("-390   0 rlineto\n");
   printf("closepath stroke\n");
-  
+
   printf(" 100 100 moveto\n");
   printf("-16    0 rlineto\n");
   printf("  0  330 rlineto\n");
   printf("422    0 rlineto\n");
   printf("  0 -330 rlineto\n");
   printf("closepath stroke\n");
-  
+
   /* Title */
   printf("/TimesLatin1 findfont 24 scalefont setfont\n");
   printf("120 400 moveto (%s) show\n", title);
   printf("/TimesLatin1 findfont 18 scalefont setfont\n");
   printf("120 375 moveto (%s) show\n", artist);
-  
+
   /* List */
   sy = 250 / i_last_track;
   if (sy > 14) sy = 14;
   printf("/labelfont /TimesLatin1 findfont %d scalefont def\n",sy-2);
   printf("/timefont /Courier findfont %d scalefont def\n",sy-2);
-  for (i = i_first_track, y = 350; i <= i_last_track; i++, y -= sy) {
-    s = cdio_audio_get_msf_seconds(&toc[i+1]) 
+  y = 350;
+  for (i = i_first_track_global; i <= i_last_track; i++, y -= sy) {
+    s = cdio_audio_get_msf_seconds(&toc[i+1])
       - cdio_audio_get_msf_seconds(&toc[i]);
-    
+
     printf("labelfont setfont\n");
     printf("120 %d moveto (%d) show\n", y, i);
     {
@@ -1340,10 +1344,10 @@ ps_list_tracks(void)
       printf("150 %d moveto (%s) show\n", y, line);
     }
     printf("timefont setfont\n");
-    printf("420 %d moveto (%2d:%02d) show\n", y, 
+    printf("420 %d moveto (%2d:%02d) show\n", y,
            s / CDIO_CD_SECS_PER_MIN, s % CDIO_CD_SECS_PER_MIN);
   }
-  
+
   /* Seitenbanner */
   printf("/HelveticaLatin1 findfont 12 scalefont setfont\n");
   printf(" 97 105 moveto (%s: %s) 90 rotate show -90 rotate\n",
@@ -1362,9 +1366,9 @@ list_tracks(void)
 
   printf("Title : %s\n", title);
   printf("Artist: %s\n", artist);
-  
-  for (i = i_first_track; i <= i_last_track; i++) {
-    s = cdio_audio_get_msf_seconds(&toc[i+1]) 
+
+  for (i = i_first_track_global; i <= i_last_track; i++) {
+    s = cdio_audio_get_msf_seconds(&toc[i+1])
       - cdio_audio_get_msf_seconds(&toc[i]);
     printf("%2d: %s [%d seconds]\n", i, cd_info[i].title, s);
   }
@@ -1388,18 +1392,18 @@ typedef enum {
 
 int
 main(int argc, char *argv[])
-{    
+{
   int  c, nostop=0;
   char *h;
   int  i_rc = 0;
   cd_operation_t cd_op = NO_OP; /* operation to do in non-interactive mode */
-  
-  
+
+
   psz_program = strrchr(argv[0],'/');
   psz_program = psz_program ? psz_program+1 : argv[0];
 
   memset(&cddb_opts, 0, sizeof(cddb_opts));
-  
+
   cdio_loglevel_default = CDIO_LOG_WARN;
   /* parse options */
   while ( 1 ) {
@@ -1408,12 +1412,12 @@ main(int argc, char *argv[])
     switch (c) {
     case 'v':
       b_verbose = true;
-      if (cdio_loglevel_default > CDIO_LOG_INFO) 
+      if (cdio_loglevel_default > CDIO_LOG_INFO)
         cdio_loglevel_default = CDIO_LOG_INFO;
       break;
     case 'd':
       debug = 1;
-      if (cdio_loglevel_default > CDIO_LOG_DEBUG) 
+      if (cdio_loglevel_default > CDIO_LOG_DEBUG)
       cdio_loglevel_default = CDIO_LOG_DEBUG;
       break;
     case 'a':
@@ -1480,9 +1484,9 @@ main(int argc, char *argv[])
       exit(1);
     }
   }
-  
+
   if (argc > optind) {
-    psz_device = strdup(argv[optind]);
+    psz_device_global = strdup(argv[optind]);
   } else {
     char **ppsz_cdda_drives=NULL;
     char **ppsz_all_cd_drives = cdio_get_devices_ret(&driver_id);
@@ -1491,17 +1495,17 @@ main(int argc, char *argv[])
       fprintf(stderr, "Can't find a CD-ROM drive\n");
       exit(2);
     }
-    ppsz_cdda_drives = cdio_get_devices_with_cap(ppsz_all_cd_drives, 
+    ppsz_cdda_drives = cdio_get_devices_with_cap(ppsz_all_cd_drives,
                                                  CDIO_FS_AUDIO, false);
     if (!ppsz_cdda_drives || !ppsz_cdda_drives[0]) {
       fprintf(stderr, "Can't find a CD-ROM drive with a CD-DA in it\n");
       exit(3);
     }
-    psz_device = strdup(ppsz_cdda_drives[0]);
+    psz_device_global = strdup(ppsz_cdda_drives[0]);
     cdio_free_device_list(ppsz_all_cd_drives);
     cdio_free_device_list(ppsz_cdda_drives);
   }
-  
+
   if (!b_interactive) {
     b_sig = true;
     nostop=1;
@@ -1517,17 +1521,17 @@ main(int argc, char *argv[])
   if (CLOSE_CD != cd_op) {
     /* open device */
     if (b_verbose)
-      fprintf(stderr, "open %s... ", psz_device);
-    p_cdio = cdio_open (psz_device, driver_id);
-    if (!p_cdio && cd_op != EJECT_CD) {
-      cd_close(psz_device);
-      p_cdio = cdio_open (psz_device, driver_id);
+      fprintf(stderr, "open %s... ", psz_device_global);
+    p_cdio_global = cdio_open (psz_device_global, driver_id);
+    if (!p_cdio_global && cd_op != EJECT_CD) {
+      cd_close(psz_device_global);
+      p_cdio_global = cdio_open (psz_device_global, driver_id);
     }
-    
-    if (p_cdio && b_verbose)
+
+    if (p_cdio_global && b_verbose)
       fprintf(stderr,"ok\n");
   }
-  
+
   if (b_interactive) {
 #ifdef HAVE_CDDB
     cddb_log_set_handler (cddb_log_handler);
@@ -1544,15 +1548,15 @@ main(int argc, char *argv[])
       case PS_LIST_TRACKS:
       case LIST_TRACKS:
       case PLAY_TRACK:
-        read_toc(p_cdio);
+        read_toc(p_cdio_global);
       default:
         break;
       }
-      if (p_cdio)
+      if (p_cdio_global)
         switch (cd_op) {
         case STOP_PLAYING:
           b_cd = true;
-          i_rc = cd_stop(p_cdio) ? 0 : 1;
+          i_rc = cd_stop(p_cdio_global) ? 0 : 1;
           break;
         case EJECT_CD:
           /* Should have been handled above. */
@@ -1582,11 +1586,11 @@ main(int argc, char *argv[])
           break;
 
         case SET_VOLUME:
-          i_rc = set_volume_level(p_cdio, i_volume_level);
+          i_rc = set_volume_level(p_cdio_global, i_volume_level);
           break;
 
-        case LIST_SUBCHANNEL: 
-          if (read_subchannel(p_cdio)) {
+        case LIST_SUBCHANNEL:
+          if (read_subchannel(p_cdio_global)) {
             if (sub.audio_status == CDIO_MMC_READ_SUB_ST_PAUSED ||
                 sub.audio_status == CDIO_MMC_READ_SUB_ST_PLAY) {
               {
@@ -1595,7 +1599,7 @@ main(int argc, char *argv[])
                        sub.abs_addr.m, sub.abs_addr.s);
               }
             }
-            printf("drive state: %s\n", 
+            printf("drive state: %s\n",
                    mmc_audio_state2str(sub.audio_status));
           } else {
             i_rc = 1;
@@ -1609,10 +1613,10 @@ main(int argc, char *argv[])
           break;
         }
       else if (CLOSE_CD == cd_op) {
-        i_rc = (DRIVER_OP_SUCCESS == cdio_close_tray(psz_device, NULL))
+        i_rc = (DRIVER_OP_SUCCESS == cdio_close_tray(psz_device_global, NULL))
                 ? 0 : 1;
       } else {
-        fprintf(stderr,"no CD in drive (%s)\n", psz_device);
+        fprintf(stderr,"no CD in drive (%s)\n", psz_device_global);
       }
     }
   }
@@ -1620,24 +1624,24 @@ main(int argc, char *argv[])
   /* Play all tracks *unless* we have a play or paused status
      already. */
 
-  read_subchannel(p_cdio);
+  read_subchannel(p_cdio_global);
   if (sub.audio_status != CDIO_MMC_READ_SUB_ST_PAUSED &&
       sub.audio_status != CDIO_MMC_READ_SUB_ST_PLAY)
     play_track(1, CDIO_CDROM_LEADOUT_TRACK);
 
   while ( !b_sig ) {
     int key;
-    if (!b_cd) read_toc(p_cdio);
-    read_subchannel(p_cdio);
+    if (!b_cd) read_toc(p_cdio_global);
+    read_subchannel(p_cdio_global);
     display_status(false);
-    
+
     if (1 == select_wait(b_cd ? 1 : 5)) {
       switch (key = getch()) {
       case '-':
-        decrease_volume_level(p_cdio);
+        decrease_volume_level(p_cdio_global);
         break;
       case '+':
-        increase_volume_level(p_cdio);
+        increase_volume_level(p_cdio_global);
         break;
       case 'A':
       case 'a':
@@ -1656,11 +1660,11 @@ main(int argc, char *argv[])
         cd_eject();
         break;
       case 's':
-        cd_stop(p_cdio);
+        cd_stop(p_cdio_global);
         break;
       case 'C':
       case 'c':
-        cd_close(psz_device);
+        cd_close(psz_device_global);
         break;
       case 'L':
       case 'l':
@@ -1669,9 +1673,9 @@ main(int argc, char *argv[])
           display_tracks();
         else {
           i_last_display_track = CDIO_INVALID_TRACK;
-          display_cdinfo(p_cdio, i_tracks, i_first_track);
+          display_cdinfo(p_cdio_global, i_tracks_global, i_first_track_global);
         }
-        
+
         break;
       case 'K':
       case 'k':
@@ -1688,7 +1692,7 @@ main(int argc, char *argv[])
       case KEY_RIGHT:
         if (b_cd &&
             (sub.audio_status == CDIO_MMC_READ_SUB_ST_PAUSED ||
-             sub.audio_status == CDIO_MMC_READ_SUB_ST_PLAY)) 
+             sub.audio_status == CDIO_MMC_READ_SUB_ST_PLAY))
           play_track(sub.track+1, CDIO_CDROM_LEADOUT_TRACK);
         else
           play_track(1,CDIO_CDROM_LEADOUT_TRACK);
@@ -1746,9 +1750,9 @@ main(int argc, char *argv[])
       }
     }
   }
-  if (!nostop) cd_stop(p_cdio);
+  if (!nostop) cd_stop(p_cdio_global);
   tty_restore();
   finish("bye", i_rc);
-  
+
   return 0; /* keep compiler happy */
 }
